@@ -11,6 +11,9 @@ from dhlab.legacy import (
 
 # code from further down in the code tree
 from dhlab.text.corpus import Corpus
-from dhlab.text.conc_coll import Collocations, Concordance
+from dhlab.text.chunking import Chunks
+from dhlab.text.conc_coll import Collocations, Concordance, Counts
 from dhlab.text.geo_data import GeoData
 from dhlab.ngram.ngram import Ngram, NgramBook, NgramNews
+
+from dhlab.wordbank.wordbank import WordParadigm, WordLemma, WordForm
\ No newline at end of file
